==> contentrules.slack-2.0.0.tar.gz: contentrules.slack-2.0.0/docs/intro.md <==
# About

**contentrules.slack** is a package providing a [Plone](https://plone.org/) content rules action to post a message on Slack.

## Code Health
<div align="center">

[![PyPI](https://img.shields.io/pypi/v/contentrules.slack)](https://pypi.org/project/contentrules.slack/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/contentrules.slack)](https://pypi.org/project/contentrules.slack/)
[![PyPI - Wheel](https://img.shields.io/pypi/wheel/contentrules.slack)](https://pypi.org/project/contentrules.slack/)
[![PyPI - License](https://img.shields.io/pypi/l/contentrules.slack)](https://pypi.org/project/contentrules.slack/)
[![PyPI - Status](https://img.shields.io/pypi/status/contentrules.slack)](https://pypi.org/project/contentrules.slack/)


[![PyPI - Plone Versions](https://img.shields.io/pypi/frameworkversions/plone/contentrules.slack)](https://pypi.org/project/contentrules.slack/)

[![Code analysis checks](https://github.com/collective/contentrules.slack/actions/workflows/code-analysis.yml/badge.svg)](https://github.com/collective/contentrules.slack/actions/workflows/code-analysis.yml)
[![Tests](https://github.com/collective/contentrules.slack/actions/workflows/tests.yaml/badge.svg)](https://github.com/collective/contentrules.slack/actions/workflows/tests.yaml)
![Code Style](https://img.shields.io/badge/Code%20Style-Black-000000)

[![GitHub contributors](https://img.shields.io/github/contributors/collective/contentrules.slack)](https://github.com/collective/contentrules.slack)
[![GitHub Repo stars](https://img.shields.io/github/stars/collective/contentrules.slack?style=social)](https://github.com/collective/contentrules.slack)

</div>

## Installation

Add **contentrules.slack** to the Plone installation using `pip`:

```bash
pip install contentrules.slack
```

or add it as a dependency on your package's `setup.py`

```python
    install_requires = [
        "contentrules.slack",
        "Plone",
        "plone.restapi",
        "setuptools",
    ],
```

Start Plone and activate the plugin in the addons control-panel.

## Translations

This product has been translated into:

- English (Érico Andrei)
- Português do Brasil (Rudá Porto)
- Deutsch (Yael Biran)
- Español (Álvaro Hurtado Mochón)

## License

The project is licensed under the GPLv2.

## One Last Thing

Originally Made in Berlin, with love, by your friends @ Briefy and Pendect.

Now maintained by the [Plone Collective](https://github.com/collective)

==> contentrules.slack-2.0.1.tar.gz: contentrules.slack-2.0.1/docs/intro.md <==
# About

**contentrules.slack** is a package providing a [Plone](https://plone.org/) content rules action to post a message on Slack.

## Code Health
<div align="center">

[![PyPI](https://img.shields.io/pypi/v/contentrules.slack)](https://pypi.org/project/contentrules.slack/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/contentrules.slack)](https://pypi.org/project/contentrules.slack/)
[![PyPI - Wheel](https://img.shields.io/pypi/wheel/contentrules.slack)](https://pypi.org/project/contentrules.slack/)
[![PyPI - License](https://img.shields.io/pypi/l/contentrules.slack)](https://pypi.org/project/contentrules.slack/)
[![PyPI - Status](https://img.shields.io/pypi/status/contentrules.slack)](https://pypi.org/project/contentrules.slack/)


[![PyPI - Plone Versions](https://img.shields.io/pypi/frameworkversions/plone/contentrules.slack)](https://pypi.org/project/contentrules.slack/)

[![Code analysis checks](https://github.com/collective/contentrules.slack/actions/workflows/code-analysis.yml/badge.svg)](https://github.com/collective/contentrules.slack/actions/workflows/code-analysis.yml)
[![Tests](https://github.com/collective/contentrules.slack/actions/workflows/tests.yml/badge.svg)](https://github.com/collective/contentrules.slack/actions/workflows/tests.yml)
![Code Style](https://img.shields.io/badge/Code%20Style-Black-000000)

[![GitHub contributors](https://img.shields.io/github/contributors/collective/contentrules.slack)](https://github.com/collective/contentrules.slack)
[![GitHub Repo stars](https://img.shields.io/github/stars/collective/contentrules.slack?style=social)](https://github.com/collective/contentrules.slack)

</div>

## Installation

Add **contentrules.slack** to the Plone installation using `pip`:

```bash
pip install contentrules.slack
```

or add it as a dependency on your package's `setup.py`

```python
    install_requires = [
        "contentrules.slack",
        "Plone",
        "plone.restapi",
        "setuptools",
    ],
```

Start Plone and activate the plugin in the addons control-panel.

## Translations

This product has been translated into:

- English (Érico Andrei)
- Português do Brasil (Rudá Porto)
- Deutsch (Yael Biran)
- Español (Álvaro Hurtado Mochón)

## License

The project is licensed under the GPLv2.

## One Last Thing

Originally Made in Berlin, with love, by your friends @ Briefy and Pendect.

Now maintained by the [Plone Collective](https://github.com/collective)
